#!/bin/sh
#
# -----------------------------------------------------------------------------
#
# ZenBuild script for Gmime
# ===========================
# Author:	Thibaud GUERIN <guth@ploposor.com>
# URL:		http://prdownloads.sourceforge.net/parchive/par2cmdline-0.3.tar.gz?download

soft='par2cmdline'
softversion='0.3'
packageversion='1z30'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/${soft}-${softversion}.tar.gz"
src="$buildir/${soft}-${softversion}"
package="${soft}-${softversion}-${arch}-${packageversion}"
dest="$buildir/${package}"


cd $buildir
rm -rf $src


#
# Extract the tar ball, patch and modify
#
echo "Extracting the program tarball..."
tar -xf $srcpkg

rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest
#chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXFLAGS="-O2 -march=i486 -mtune=$cpu"

cd $src


echo "Building ..."
./configure --prefix=/usr --localstatedir=/var --sysconfdir=/etc --mandir=/usr/man
make
make install DESTDIR=$dest
cd ..

mkdir -p $dest/usr/bin
mkdir -p $dest/usr/man/man1

chown -R root.root $dest

# No icon
# No .desktop

( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)


## --- DOCUMENTATION ---
echo "Building Doc"
rm -rf $dest/usr/share/doc
mkdir -p $dest/usr/doc/$soft-$softversion

# Unpack the separate documentation tarball
cd $src
cp -a AUTHORS COPYING TODO LICENCE.TXT README Changelog docs $dest/usr/doc/$soft-$softversion
cd ..
chown -R root.root $dest/usr/doc/$soft-$softversion/*
chmod -R a-ws $dest/usr/doc/$soft-$softversion/*

# Compress the man pages
gzip -9f $dest/usr/man/*/*


# --- PACKAGE DESCRIPTION ---
mkdir -p $dest/install

cat <<EOF > $dest/install/slack-desc
#       |-----handy-ruler------------------------------------------------------|
$soft: par2cmdline 0.1 Zenwalk Package
$soft:
$soft: A command line implementation of the PAR v2.0 specification. Currently
$soft: compiles under Win32, cygwin, and various unix flavors with gcc.
$soft: 
$soft: par2cmdline is under GPL licence.
$soft: 
$soft: 
$soft: 
$soft: 
$soft: 
EOF

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

# --- OWNERSHIP, RIGHTS ---

chmod -R o-w $dest


# --- BUILDING ---

echo "Build package"
cd $dest
/sbin/makepkg -l y -c n $dest.tgz

